Bifrost: UnitigMapBase Class Reference

Bifrost

Public Member Functions | Data Fields
UnitigMapBase Class Reference

Structure containing the basic information of a unitig mapping. More...

Inherited by UnitigMap< Unitig_data_t, Graph_data_t, is_const >, and UnitigMap< U, G, is_const >.

## Public Member Functions
| UnitigMapBase (const size_t length=1)
| UnitigMapBase constructor (isEmpty = true). More...
| UnitigMapBase (const size_t start, const size_t length, const size_t unitig_sz, const bool strand)
| UnitigMapBase constructor (isEmpty = false). More...
bool | operator== (const UnitigMapBase &o) const
| Equality operator: check if two UnitigMapBase are the same. More...
bool | operator!= (const UnitigMapBase &o) const
| Inequality operator: check if two UnitigMapBase are different. More...

## Data Fields
size_t | dist
| Start position of the mapping (0-based distance) from the start of the reference unitig.
size_t | len
| Length of the mapping on the reference unitig, in k-mers.
size_t | size
| Length of the reference unitig.
bool | strand
| True if the mapped k-mer or sequence matches the forward strand, false if it matches its reverse-complement.
bool | isEmpty
| True if there is no mapping.

## Detailed Description

Structure containing the basic information of a unitig mapping.

This structure is independent from the graph. It is the base class for the class UnitigMap.

## Constructor & Destructor Documentation

## ◆ UnitigMapBase() [1/2]

UnitigMapBase::UnitigMapBase | ( | const size_t | length = `1` | ) |

UnitigMapBase constructor (isEmpty = true).

Parameters

  length | is the length of the mapping in k-mers (default is 1 k-mer).

Returns
  an empty UnitigMapBase.

## ◆ UnitigMapBase() [2/2]

UnitigMapBase::UnitigMapBase | ( | const size_t | start,
|  | const size_t | length,
|  | const size_t | unitig_sz,
|  | const bool | strand
| ) |  |

UnitigMapBase constructor (isEmpty = false).

Parameters

  start | is the start position of the mapping (0-based distance) from the start of the reference unitig.
  length | is the length of the mapping in k-mers.
  unitig_sz | is the length of the reference unitig used for the mapping.
  strand | indicates if the mapped k-mer or sequence matches the forward strand (true) or the reverse-complement (false).

Returns
  a UnitigMapBase.

## Member Function Documentation

## ◆ operator!=()

bool UnitigMapBase::operator!= | ( | const UnitigMapBase & | o | ) | const

Inequality operator: check if two UnitigMapBase are different.

Returns
  a boolean indicating if the two UnitigMapBase are different.

## ◆ operator==()

bool UnitigMapBase::operator== | ( | const UnitigMapBase & | o | ) | const

Equality operator: check if two UnitigMapBase are the same.

Returns
  a boolean indicating if two UnitigMapBase are the same.

The documentation for this class was generated from the following file:

- src/UnitigMap.hpp